==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/sr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Здружено дељење",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Да ли желите да додате удаљено дељење {name} од {owner}@{remote}?",
    "Remote share" : "Удаљено дељење",
    "Remote share password" : "Лозинка удаљеног дељења",
    "Cancel" : "Одустани",
    "Add remote share" : "Додај удаљено дељење",
    "Copy" : "Копирај",
    "Copied!" : "Копирано!",
    "Not supported!" : "Није подржано!",
    "Press ⌘-C to copy." : "Притисните ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисните Ctrl-C за копирање.",
    "Invalid Federated Cloud ID" : "Неисправан ИД Здруженог облака",
    "Server to server sharing is not enabled on this server" : "Сервер-сервер дељење није подржано на овом серверу",
    "Couldn't establish a federated share." : "Не могу да успоставим здружено дељење.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не могу да успоставим здружено дељење, можда лозинка не ваља.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Послат захтев за здружено дељење, добићете позивницу. Проверавајте обавештења.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не могу да успоставим здружено дељење, изгледа да је сервер са којим се треба здружити превише стар (Некстклауд верзија <=9).",
    "It is not allowed to send federated group shares from this server." : "Са овог сервера није дозвољено да шаљете групна дељења ка здруженим серверима.",
    "Not allowed to create a federated share with the same user" : "Није дозвољено да се направи здружено дељење са истим корисником",
    "File is already shared with %s" : "Фајл је већ дељен са %s",
    "Could not find share" : "Не могу да пронађем дељење",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Примили сте \"%3$s\" као удаљено дељење од %1$s (у име %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Примили сте {share} као удаљено дељење од {user} (у име {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Примили сте \"%3$s\" као удаљено дељење од %1$s",
    "You received {share} as a remote share from {user}" : "Примили сте {share} као удаљено дељење од {user}",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Дели са мном преко мог #Некстклауд Здруженог облака, види %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Дели са мном преко мог #Некстклауд Здруженог облака",
    "Sharing" : "Дељење",
    "Federated file sharing" : "Здружено дељење фајлова",
    "Provide federated file sharing across servers" : "Пружа здружено дељење фајлова између сервера",
    "Federated Cloud Sharing" : "Здружено дељење у облаку",
    "Open documentation" : "Отвори документацију",
    "Adjust how people can share between servers." : "Подеси како људи деле фајлове између сервера.",
    "Allow users on this server to send shares to other servers" : "Дозвољава корисницима овог сервера да шаљу дељења на друге сервере",
    "Allow users on this server to receive shares from other servers" : "Дозвољава корисницима овог сервера да примају дељења са других сервера",
    "Allow users on this server to send shares to groups on other servers" : "Дозволи корисницима са овог сервера да деле са групама на другим серверима",
    "Allow users on this server to receive group shares from other servers" : "Дозволи корисницима на овом серверу да примају групна дељења са других сервера",
    "Search global and public address book for users" : "Тражи кориснике и у глобалним и јавним именицима",
    "Allow users to publish their data to a global and public address book" : "Дозволи корисницима да објаве своје податке у јавне и глобалне именике",
    "Federated Cloud" : "Здружени облак",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можете делите ствари са било ким ко користи Некстклауд, Оунклауд или Пидио. Само унесите њихов ИД Здруженог Облака у дијалог за дељење. ИД изгледа нешто попут person@cloud.example.com",
    "Your Federated Cloud ID:" : "ИД вашег здруженог облака:",
    "Share it so your friends can share files with you:" : "Поделите да би Ваши пријатељи могли да деле са Вама:",
    "Add to your website" : "Додај на свој веб сајт",
    "Share with me via Nextcloud" : "Дели са мном преко Некстклауда",
    "HTML Code:" : "ХТМЛ кôд:",
    "The mountpoint name contains invalid characters." : "Име тачке монтирања садржи неисправне карактере.",
    "Not allowed to create a federated share with the owner." : "Није дозвољено да направите здружено дељење са власником.",
    "Invalid or untrusted SSL certificate" : "Неисправан или SSL сертификат без поверења",
    "Could not authenticate to remote share, password might be wrong" : "Удаљено дељење не може да провери Ваш идентитет, можда лозинка није исправна",
    "Storage not valid" : "Складиште није исправно",
    "Federated share added" : "Здружено дељење додато",
    "Couldn't add remote share" : "Не могу да додам удаљено дељење",
    "Sharing %s failed, because this item is already shared with %s" : "Дељење %s није успело зато што се ова ставка већ дели са %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Дељење %s није успело, не могу да нађем %s, можда сервер тренутно није доступан или користи самопотписани сертификат.",
    "Search global and public address book for users and let local users publish their data" : "Претражи кориснике у глобалним и јавним именицима и дозволи да локални корисници објављују њихове податке"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/sr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Здружено дељење",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Да ли желите да додате удаљено дељење {name} од {owner}@{remote}?",
    "Remote share" : "Удаљено дељење",
    "Remote share password" : "Лозинка удаљеног дељења",
    "Cancel" : "Одустани",
    "Add remote share" : "Додај удаљено дељење",
    "Copy" : "Копирај",
    "Copied!" : "Копирано!",
    "Not supported!" : "Није подржано!",
    "Press ⌘-C to copy." : "Притисните ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисните Ctrl-C за копирање.",
    "Invalid Federated Cloud ID" : "Неисправан ИД Здруженог облака",
    "Server to server sharing is not enabled on this server" : "Сервер-сервер дељење није подржано на овом серверу",
    "Couldn't establish a federated share." : "Не могу да успоставим здружено дељење.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не могу да успоставим здружено дељење, можда лозинка не ваља.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Послат захтев за здружено дељење, добићете позивницу. Проверавајте обавештења.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не могу да успоставим здружено дељење, изгледа да је сервер са којим се треба здружити превише стар (Некстклауд верзија <=9).",
    "It is not allowed to send federated group shares from this server." : "Са овог сервера није дозвољено да шаљете групна дељења ка здруженим серверима.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Дељење %1$s није успело зато што се ова ставка већ дели са %2$s",
    "Not allowed to create a federated share with the same user" : "Није дозвољено да се направи здружено дељење са истим корисником",
    "File is already shared with %s" : "Фајл је већ дељен са %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Дељење %1$s није успело, не могу да нађем %2$s, можда сервер тренутно није доступан или користи самопотписани сертификат.",
    "Could not find share" : "Не могу да пронађем дељење",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Примили сте \"%3$s\" као удаљено дељење од %1$s (у име %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Примили сте {share} као удаљено дељење од {user} (у име {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Примили сте \"%3$s\" као удаљено дељење од %1$s",
    "You received {share} as a remote share from {user}" : "Примили сте {share} као удаљено дељење од {user}",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Дели са мном преко мог #Некстклауд Здруженог облака, види %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Дели са мном преко мог #Некстклауд Здруженог облака",
    "Sharing" : "Дељење",
    "Federated file sharing" : "Здружено дељење фајлова",
    "Provide federated file sharing across servers" : "Пружа здружено дељење фајлова између сервера",
    "Federated Cloud Sharing" : "Здружено дељење у облаку",
    "Open documentation" : "Отвори документацију",
    "Adjust how people can share between servers." : "Подеси како људи деле фајлове између сервера.",
    "Allow users on this server to send shares to other servers" : "Дозвољава корисницима овог сервера да шаљу дељења на друге сервере",
    "Allow users on this server to receive shares from other servers" : "Дозвољава корисницима овог сервера да примају дељења са других сервера",
    "Allow users on this server to send shares to groups on other servers" : "Дозволи корисницима са овог сервера да деле са групама на другим серверима",
    "Allow users on this server to receive group shares from other servers" : "Дозволи корисницима на овом серверу да примају групна дељења са других сервера",
    "Search global and public address book for users" : "Тражи кориснике и у глобалним и јавним именицима",
    "Allow users to publish their data to a global and public address book" : "Дозволи корисницима да објаве своје податке у јавне и глобалне именике",
    "Federated Cloud" : "Здружени облак",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можете делите ствари са било ким ко користи Некстклауд, Оунклауд или Пидио. Само унесите њихов ИД Здруженог Облака у дијалог за дељење. ИД изгледа нешто попут person@cloud.example.com",
    "Your Federated Cloud ID:" : "ИД вашег здруженог облака:",
    "Share it so your friends can share files with you:" : "Поделите да би Ваши пријатељи могли да деле са Вама:",
    "Add to your website" : "Додај на свој веб сајт",
    "Share with me via Nextcloud" : "Дели са мном преко Некстклауда",
    "HTML Code:" : "ХТМЛ кôд:",
    "The mountpoint name contains invalid characters." : "Име тачке монтирања садржи неисправне карактере.",
    "Not allowed to create a federated share with the owner." : "Није дозвољено да направите здружено дељење са власником.",
    "Invalid or untrusted SSL certificate" : "Неисправан или SSL сертификат без поверења",
    "Could not authenticate to remote share, password might be wrong" : "Удаљено дељење не може да провери Ваш идентитет, можда лозинка није исправна",
    "Storage not valid" : "Складиште није исправно",
    "Federated share added" : "Здружено дељење додато",
    "Couldn't add remote share" : "Не могу да додам удаљено дељење",
    "Sharing %s failed, because this item is already shared with %s" : "Дељење %s није успело зато што се ова ставка већ дели са %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Дељење %s није успело, не могу да нађем %s, можда сервер тренутно није доступан или користи самопотписани сертификат.",
    "Search global and public address book for users and let local users publish their data" : "Претражи кориснике у глобалним и јавним именицима и дозволи да локални корисници објављују њихове податке"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
